@@ -23,7 +23,8 @@ typedef enum
   GLADE_PAGE_COMMON,
   GLADE_PAGE_PACKING,
   GLADE_PAGE_ATK,
-  GLADE_PAGE_QUERY
+  GLADE_PAGE_QUERY,
+  GLADE_PAGE_SIGNAL
 } GladeEditorPageType;
 
 
