@@ -47,6 +47,8 @@ void         glade_editor_load_widget        (GladeEditor       *editor,
 					      GladeWidget       *widget);
 void         glade_editor_show_info          (GladeEditor       *editor);
 void         glade_editor_hide_info          (GladeEditor       *editor);
+void         glade_editor_show_class_field   (GladeEditor       *editor);
+void         glade_editor_hide_class_field   (GladeEditor       *editor);
 
 gboolean     glade_editor_query_dialog       (GladeWidget       *widget);
 GtkWidget   *glade_editor_dialog_for_widget  (GladeWidget       *widget);
